#! /usr/bin/python
# (c) 1999 by Mirko Zeibig <mz@webideal.de>
# $Id: rh_isdnconf.py,v 1.4 1999/12/29 19:23:37 mirko Exp $
#
# This file defines structures for rh_isdn.py
NET_SCRIPT='/etc/sysconfig/network-scripts/ifcfg-ippp0'
#NET_SCRIPT='./ifcfg-ippp0'
PAP_PATH='/etc/ppp/pap-secrets'
#PAP_PATH='./pap-secrets'
ISDN_RC='/etc/sysconfig/isdn'
#ISDN_RC='./isdn'
CALLERID='/etc/isdn/callerid.conf'
OPTIONS='/etc/ppp/ippp0.d/options'
#OPTIONS='./options'
ISDNCONF='/etc/isdn/isdn.conf'
#ISDNCONF='./isdn.conf'

sTitle='rh-isdn Konfigurator 0.59 '

# have all settings for ifcfg in one dictionary
dctDLG={
	'ISDN': {
		'TITLE': 'Hardware-Config',
		'DLG_STRINGS': ['I4L_ISDNLOG','I4L_DRIVER','I4L_TYPE','I4L_IRQ','I4L_IO','I4L_MEM','DYNAMIC_IP'],
		'SAV_STRINGS': ['I4L_ISDNLOG','I4L_DEBUG','I4L_VERBOSE','I4L_PROTOCOL','I4L_DRIVER','I4L_ID','I4L_TYPE','I4L_IRQ','I4L_IO','I4L_MEM','DYNAMIC_IP'],
		'KEYS': {
			'I4L_ISDNLOG': {
				'VALUE': ['yes','no'],
				'HELP': 'Start isdnlog?',
				'COMMENT': 'Start isdnlog ("yes" or "no")'
			},
			'I4L_DEBUG': {
				'VALUE': '4',
				'HELP': '',
				'COMMENT': 'Hisax Debug Level, 4 (some..) to 31 (all messages)'
			},
			'I4L_VERBOSE': {
				'VALUE': '3',
				'HELP': '',
				'COMMENT': 'ISDNCTRL verbose level'
			},
			'I4L_PROTOCOL': {
				'VALUE': '2',
				'HELP': '',
				'COMMENT': 'D-channel protocol 1=1TR6, 2=EDSS1(Euro-ISDN) for Teles/HiSax'
			},
			'I4L_DRIVER': {
				'VALUE': 'hisax',
				'HELP': 'Card-Driver',
				'COMMENT': 'Have a look at /usr/src/linux/Documentation/isdn/'
			},
			'I4L_ID': {
				'VALUE': 'HiSax',
				'HELP': '',
				'COMMENT': 'A string describing your card'
			},
			'I4L_TYPE': {
				'VALUE': '7',
				'HELP': 'Cardtype',
				'COMMENT': '7 = Elsa QuikStep, Have a look at /usr/src/linux/Documentation/isdn/'
			},
			'I4L_IRQ': {
				'VALUE': '12',
				'HELP': 'isapnp.conf?',
				'COMMENT': 'Make sure to set to the same value as in /etc/isapnp.conf'
			},
			'I4L_IO': {
				'VALUE': '0x0360',
				'HELP': 'isapnp.conf?',
				'COMMENT': 'Make sure to set to the same value as in /etc/isapnp.conf'
			},
			'I4L_MEM': {
				'VALUE': '' ,
				'HELP': 'isapnp.conf?',
				'COMMENT': 'Make sure to set to the same value as in /etc/isapnp.conf'
			},
			'DYNAMIC_IP': {
				'VALUE': ['yes','no'],
				'HELP': 'Need dynamic IP?',
				'COMMENT': 'most ISPs only provide dynamic IPs, set this to "yes"'
			}
		}
	},
	'IFCFG': {
		'TITLE':'Device configuration',
		'DLG_STRINGS':['IPADDR','REMOTEADDR','DIALMODE','ONBOOT','EAZ','PHONE_OUT','SLAVE','GET_DNS'],
		'SAV_STRINGS':['DEVICE','IPADDR','REMOTEADDR','DIALMODE','ONBOOT','EAZ','PHONE_OUT','PHONE_IN','SLAVE','GET_DNS'],
		'KEYS': {
			'DEVICE': {
				'VALUE': 'ippp0',
				'HELP': 'Device to use?',
				'COMMENT': 'Which Device do you want to use?'
			},
			'IPADDR': {
				'VALUE': '192.168.100.1',
				'HELP': 'Your IP',
				'COMMENT': 'If this does not conflict with one of your internal devices, you may live with the default for dyn. IP'
			},
			'REMOTEADDR': {
				'VALUE': '192.168.100.2',
				'HELP': "ISP's IP",
				'COMMENT': 'If this does not conflict with one of your internal devices, you may live with the default for dyn. IP'
			},
			'DIALMODE': {
				'VALUE': ['auto','manual'],
				'HELP': 'Automatic dial-out?',
				'COMMENT': 'Set this to auto if you want ipppd to automatically connect on request'
			},
			'ONBOOT': {
				'VALUE': ['yes','no'],
				'HELP': 'Device on boot?',
				'COMMENT':'Should the device be brought up at boot time?'
			},
			'EAZ': {
				'VALUE': 'nodefault',
				'HELP': 'Your phone-number?',
				'COMMENT': 'Your phone-number, important for isdnlog'
			},
			'PHONE_OUT': {
				'VALUE':'nodefault',
				'HELP': "ISP's phone-number(s)",
				'COMMENT':"Your Provider's phone-number (more than one number seperated by spaces)?"
			},
			'PHONE_IN': {
				'VALUE':'nodefault',
				'HELP': "Dialin number(s)",
				'COMMENT':"Which numbers are allowed to dialin (more than one number seperated by spaces)?"
			},
			'SLAVE': {
				'VALUE':['no','yes'],
				'HELP': 'Slave-Device?',
				'COMMENT':'If you want channel-bundling please set this to your slave-device'
			},
			'GET_DNS': {
				'VALUE':['no','yes'],
				'HELP': 'Automatic nameservers?',
				'COMMENT':'Setting this to yes will change resolv.conf for you (requires new ipppd)'
			}
		}
	},
	'AUTHCFG': {
		'TITLE': 'PAP configuration',
		'DLG_STRINGS':['PAP_USER','PAP_PASS'],
		'SAV_STRINGS':['PAP_USER','PAP_PASS'],
		'KEYS': {
			'PAP_USER': {
				'VALUE': 'nodefault',
				'HELP': 'PAP-UserName',
				'COMMENT':'Your PAP-UserName'
			},
			'PAP_PASS': {
				'VALUE': 'nodefault',
				'HELP': 'PAP-Password',
				'COMMENT':'Your PAP-Password'
			}
		}
	},
	'ISDNCONF': {
		'TITLE': ' ISDN configuration',
		'DLG_STRINGS':['COUNTRYPREFIX','COUNTRYCODE','AREAPREFIX','AREACODE'],
		'SAV_STRINGS':['COUNTRYPREFIX','COUNTRYCODE','AREAPREFIX','AREACODE'],
		'KEYS': {
			'COUNTRYPREFIX': {
				'VALUE': '+',
				'HELP': 'Country-Prefix',
				'COMMENT':'The prefix for dialing outdoors'
			},
			'COUNTRYCODE': {
				'VALUE': '49',
				'HELP': 'Your country-code (e.g. 49 for Germany)',
				'COMMENT':'Country-Code'
			},
			'AREAPREFIX': {
				'VALUE': '0',
				'HELP': 'Prefix for national long distance calls',
				'COMMENT':'Area-Prefix'
			},
			'AREACODE': {
				'VALUE': '721',
				'HELP': 'Your area-code (without leading 0!)',
				'COMMENT':'Area-Code'
			}
		}
	}
}

dlgCFGS=['ISDN','IFCFG','AUTHCFG','ISDNCONF']

